.. mpmath documentation master file, created by sphinx-quickstart on Fri Mar 28 13:50:14 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mpmath's documentation!
==================================

Mpmath is a Python library for arbitrary-precision floating-point arithmetic.
For general information about mpmath, see the project website https://mpmath.org/

These documentation pages include general information as well as docstring listing with extensive use of examples that can be run in the interactive Python interpreter. For quick access to the docstrings of individual functions, use the `index listing <genindex.html>`_, or type ``help(mpmath.function_name)`` in the Python interactive prompt.

Introduction
------------

.. toctree ::
   :maxdepth: 2

   setup
   basics

Basic features
----------------

.. toctree ::
   :maxdepth: 2

   contexts
   general
   plotting
   cli

Advanced mathematics
--------------------

On top of its support for arbitrary-precision arithmetic, mpmath
provides extensive support for transcendental functions, evaluation of sums, integrals, limits, roots, and so on.

.. toctree ::
   :maxdepth: 2

   functions/index
   calculus/index
   matrices
   identification

End matter
----------

.. toctree ::
   :maxdepth: 2

   technical
   references
   genindex
